## The command interpreter for restate's e2e verification test

This is a work in progress, currently it implements the L0 object interpreter,
and requires the other verification services will be deployed separately.

## Build

```
docker build . -t e2e-py-services:main
```


